==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/CancelButtonClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CancelButtonClickEventArgsDescription } from "./CancelButtonClickEventArgsDescription";
/**
 * @hidden
 */
export let CancelButtonClickEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CancelButtonClickEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CancelButtonClickEventArgsDescriptionMetadata.a == null) {
                CancelButtonClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CancelButtonClickEventArgsDescriptionMetadata.c(CancelButtonClickEventArgsDescriptionMetadata.a);
            }
            if (a.j(CancelButtonClickEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(CancelButtonClickEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            CancelButtonClickEventArgsDescriptionMetadata.b(a);
            a.aa("CancelButtonClickEventArgs", () => new CancelButtonClickEventArgsDescription());
            a.z("CancelButtonClickEventArgs", CancelButtonClickEventArgsDescriptionMetadata.a);
        }
    }
    CancelButtonClickEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(CancelButtonClickEventArgsDescriptionMetadata, 'CancelButtonClickEventArgsDescriptionMetadata');
    CancelButtonClickEventArgsDescriptionMetadata.a = null;
    return CancelButtonClickEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/CancelButtonClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CancelButtonClickEventArgsDescription } from "./CancelButtonClickEventArgsDescription";
/**
 * @hidden
 */
export let CancelButtonClickEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CancelButtonClickEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CancelButtonClickEventArgsDescriptionMetadata.a == null) {
                CancelButtonClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CancelButtonClickEventArgsDescriptionMetadata.c(CancelButtonClickEventArgsDescriptionMetadata.a);
            }
            if (a.k(CancelButtonClickEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(CancelButtonClickEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            CancelButtonClickEventArgsDescriptionMetadata.b(a);
            a.ac("CancelButtonClickEventArgs", () => new CancelButtonClickEventArgsDescription());
            a.ab("CancelButtonClickEventArgs", CancelButtonClickEventArgsDescriptionMetadata.a);
        }
    }
    CancelButtonClickEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(CancelButtonClickEventArgsDescriptionMetadata, 'CancelButtonClickEventArgsDescriptionMetadata');
    CancelButtonClickEventArgsDescriptionMetadata.a = null;
    return CancelButtonClickEventArgsDescriptionMetadata;
})();
